@@ -8,10 +8,17 @@ import jsii
 import jsii.compat
 import publication
 
+import aws_cdk.aws_ec2._jsii
 import aws_cdk.core._jsii
+import aws_cdk.custom_resources._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-globalaccelerator", "1.49.1", __name__[0:-6], "aws-globalaccelerator@1.49.1.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-cdk/aws-globalaccelerator",
+    "1.59.0",
+    __name__[0:-6],
+    "aws-globalaccelerator@1.59.0.jsii.tgz",
+)
 
 __all__ = [
     "__jsii_assembly__",
